@@ -11,6 +11,8 @@ sub new
 
   $args{requires}->{'Dist::Zilla::PluginBundle::Git'} = 0
     if $] >= 5.010001 && $^O ne 'MSWin32';
+  $args{requires}->{'Dist::Zilla::Plugin::PkgVersion::Block'} = 0
+    if $] >= 5.014;
 
   my $self = $class->SUPER::new(%args);
   
